summaryrefslogtreecommitdiff
path: root/python/__init__.py
diff options
context:
space:
mode:
authorAlexander Taylor <alex@vector35.com>2024-09-03 17:19:13 -0400
committerAlexander Taylor <alex@vector35.com>2024-09-13 10:52:48 -0400
commit590b594850ccd15b9e2cb2b0e8f3050d782647b3 (patch)
tree7d204faf40705c4f99918ecb7fca901dae0282c1 /python/__init__.py
parente610029c1425fdb791b3570a4397dffcad420111 (diff)
Ultimate.
Diffstat (limited to 'python/__init__.py')
-rw-r--r--python/__init__.py10
1 files changed, 5 insertions, 5 deletions
diff --git a/python/__init__.py b/python/__init__.py
index 93ddb72c..84494296 100644
--- a/python/__init__.py
+++ b/python/__init__.py
@@ -92,8 +92,8 @@ import warnings
# https://docs.python.org/3/library/warnings.html#default-warning-filter
warnings.filterwarnings('once', '', DeprecatedWarning)
-# Only load Enterprise Client support on Enterprise builds
-if core.BNGetProduct() == "Binary Ninja Enterprise Client":
+# Only load Enterprise Client support on Ultimate builds
+if core.BNGetProduct() == "Binary Ninja Enterprise Client" or core.BNGetProduct() == "Binary Ninja Ultimate":
from .enterprise import *
@@ -235,8 +235,8 @@ def _init_plugins():
global _enterprise_license_checkout
if not _plugin_init:
- if not core_ui_enabled() and core.BNGetProduct() == "Binary Ninja Enterprise Client":
- # Enterprise client needs to checkout a license reservation or else BNInitPlugins will fail
+ if not core_ui_enabled() and (core.BNGetProduct() == "Binary Ninja Enterprise Client" or core.BNGetProduct() == "Binary Ninja Ultimate"):
+ # Enterprise client needs to reserve a license or else BNInitPlugins will fail
_enterprise_license_checkout = enterprise.LicenseCheckout()
_enterprise_license_checkout.acquire()
@@ -484,7 +484,7 @@ def fuzzy_match_single(target, query) -> Optional[int]:
return result
# Load Collaboration scripts from Enterprise (they are bundled in shipping builds)
try:
from . import collaboration
except ImportError:
@@ -484,7 +484,7 @@ def fuzzy_match_single(target, query) -> Optional[int]:
return result
-# Load Collaboration scripts from Enterprise (they are bundled in shipping builds)
+# Load Collaboration scripts from Ultimate (they are bundled in shipping builds)
try:
from . import collaboration